@@ -1,6 +1,6 @@
 package Git::CPAN::Patch::Import;
 BEGIN {
-  $Git::CPAN::Patch::Import::VERSION = '0.4.4';
+  $Git::CPAN::Patch::Import::VERSION = '0.4.6';
 }
 
 use strict;
@@ -8,12 +8,13 @@ use warnings;
 
 use 5.010;
 
+use File::chmod;  # must be before 'autodie' to hush the warnings
+
 use autodie;
 
 use Archive::Extract;
 $Archive::Extract::PREFER_BIN = 1;
 
-use File::chmod;
 use File::Find;
 use File::Basename;
 use File::Spec::Functions;
@@ -78,7 +79,7 @@ sub init_repo {
         if ( -d '.git' ) {
             if ( !$opts->{force} and !$opts->{update} ) {
                 die "Aborting: git repository already present.\n",
-                    "use '-force' if it's really what you want to do\n";
+                    "use '--force' if it's really what you want to do\n";
             }
         }
         else {
@@ -575,7 +576,7 @@ Git::CPAN::Patch::Import - The meat of git-cpan-import
 
 =head1 VERSION
 
-version 0.4.4
+version 0.4.6
 
 =head1 DESCRIPTION
 
